import React, { useState } from "react";
import { Disclosure } from "@headlessui/react";
import {
  CloseDisclosure,
  OpenDisclosure,
  UploadIcon,
} from "@/components/Icons";

export const DocumentTab = () => {
  const [file, setFile] = useState(null);
  const [error, setError] = useState(null);

  const handleFileChange = (e) => {
    const selectedFile = e.target.files[0];
    const allowedTypes = [
      "application/pdf",
      "application/msword",
      "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
    ];

    if (selectedFile && allowedTypes.includes(selectedFile.type)) {
      setFile(selectedFile);
      setError(null);
    } else {
      setFile(null);
      setError("Only PDF and Word documents are allowed.");
    }
  };
  const handleRemoveFile = () => {
    setFile(null);
    setError(null);
  };
  const options = [
    "Passport",
    "Driver's License",
    "National ID Card",
    "Utility bills (e.g., electricity, water, gas)",
    "Bank statements",
    "Rental agreement or mortgage statement",
    "Tax returns",
    "Proof of income",
    "Property deeds",
    "Vehicle registration documents",
    "Stock certificates",
    "Power of Attorney",
    "Trust documents",
    "Will and testament",
    "Business registration/license",
    "Articles of incorporation",
    "Financial statements",
    "Health insurance card",
    "Property insurance policy",
    "Anti-money laundering (AML) compliance documents",
    "Know Your Customer (KYC) information",
  ];
  return (
    <>
      <span className="text-lg text-prussianBlue/40 mb-4 block">
        Deal Hunter
      </span>
      <div className="custom-shadow rounded px-8 py-5 mb-5">
        <p>
          {
            "Welcome to document storage! We know how important efficiency and ease are in financial and legal processes. Uploading your documents here protects your sensitive data and simplifies future transactions."
          }
        </p>
        <p>
          {
            "Our platform securely stores your papers, eliminating the need to scan and upload them for multiple transactions. Knowing where your documents are can save you time for bank transactions, evaluations, trust agreements, and regulatory compliance."
          }
        </p>
        <p>
          {
            "The central location makes it easy to view your documents anytime you need them. No more hunting through piles of paperwork or computer files—everything you need is just a few clicks away."
          }
        </p>
        <p>
          {
            "Rest assured that we prioritize your privacy and security. Only authorized people can access your encrypted documents."
          }
        </p>
        <p>
          {
            "Use this convenient feature for easy transactions. Upload your documents today to simplify financial and legal management on our site."
          }
        </p>
      </div>
      <div className="custom-shadow rounded flex flex-col gap-2">
        <Disclosure as="div" className={`disclosure`} defaultOpen={true}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Documents Storage
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="">
                <div className="border-b">
                  <div className="flex justify-center py-3">
                    <select
                      name=""
                      id=""
                      className="shadow-neons rounded w-full md:w-[50%] h-[48px] pl-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                    >
                      {options.map((ele, i) => (
                        <option key={i} value={ele}>
                          {ele}
                        </option>
                      ))}
                    </select>
                  </div>
                  <label
                    onChange={handleFileChange}
                    className="flex cursor-pointer flex-col py-11 justify-center items-center"
                    htmlFor="upload"
                  >
                    <input type="file" name="" id="upload" className="hidden" />
                    <UploadIcon className="mb-2" />
                    <span className="custom-shadow rounded py-3 px-7 font-medium mb-3">
                      Upload Documents
                    </span>
                    <span className="text-black/30">
                      Maximum file size: 2MB
                    </span>
                  </label>
                  {error && <p className="text-red-600 mb-4">{error}</p>}
                  {file && (
                    <div className="flex items-center gap-4 px-4 mb-4">
                      <p className="font-medium">{file.name}</p>
                      <button
                        onClick={handleRemoveFile}
                        className="  bg-red-600 text-white rounded-full h-[20px] w-[20px] flex items-center justify-center text-xl hover:bg-red-700 transition"
                      >
                        &times;
                      </button>
                    </div>
                  )}
                </div>
                <div className="grid sm:grid-cols-2 p-8">
                  <div>
                    <p>1. Identification Documents:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Passport</li>
                      <li>Driver's License</li>
                      <li>National ID Card</li>
                    </ul>
                    <p>2. Proof of Address:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Utility bills (e.g., electricity, water, gas)</li>
                      <li>Bank statements</li>
                      <li>Rental agreement or mortgage statement</li>
                    </ul>
                    <p>3. Financial Documents:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Bank statements</li>
                      <li>Tax returns</li>
                      <li>
                        Proof of income (e.g., pay stubs, employment contract)
                      </li>
                    </ul>
                    <p>4. Asset Ownership Documents:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Property deeds</li>
                      <li>Vehicle registration documents</li>
                      <li>Stock certificates</li>
                    </ul>
                  </div>
                  <div>
                    <p>5. Legal Documents:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Power of Attorney</li>
                      <li>Trust documents</li>
                      <li>Will and testament</li>
                    </ul>
                    <p>6. Business Documents (if applicable):</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Business registration/license</li>
                      <li>Articles of incorporation</li>
                      <li>Financial statements</li>
                    </ul>
                    <p>7. Insurance Documents:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Health insurance card</li>
                      <li>Property insurance policy</li>
                    </ul>
                    <p>8. Legal Compliance Documents:</p>
                    <ul className="list-disc pl-5 mb-4">
                      <li>Anti-money laundering (AML) compliance documents</li>
                      <li>Know Your Customer (KYC) information</li>
                    </ul>
                  </div>
                </div>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
      </div>
    </>
  );
};
